/*
  Copyright (c) 2007 Kathryn Huxtable

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.

  $Id: TimeUtil.java 1041 2007-04-07 15:05:18Z huxtable $
 */
package org.kathrynhuxtable.middleware.shibshim.util;

import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.TimeZone;

/**
 * Miscellaneous utility methods.
 */
public class TimeUtil {

	/**
	 * Formats a given string to YYYY-MM-DDTHH:MM:ss.SSSZ
	 * 
	 * @param timeStr
	 *            Input string
	 * 
	 * @return formatted string.
	 */
	public static String formatToGMT(String  timeStr) {
		if (timeStr.equals("0"))
			return "1970-01-01T00:00:00.000Z";

		String[] timeStrArr = timeStr.split(":");
		Calendar cal = new GregorianCalendar(Integer.parseInt(timeStrArr[0]),
										   Integer.parseInt(timeStrArr[1]) - 1,
										   Integer.parseInt(timeStrArr[2]),
										   Integer.parseInt(timeStrArr[3]),
										   Integer.parseInt(timeStrArr[4]),
										   Integer.parseInt(timeStrArr[5]));
		return formatToGMT(cal.getTime());
	}

	/**
	 * Formats a given string to YYYY-MM-DDTHH:MM:ss.SSSZ
	 * 
	 * @param dtObj
	 *            Date object
	 * 
	 * @return formatted string.
	 */
	public static String formatToGMT(Date dtObj) {
		SimpleDateFormat dFormat = new SimpleDateFormat("yyyy-MM-dd");
		dFormat.setTimeZone(TimeZone.getTimeZone("GMT"));
		SimpleDateFormat dFormat1 = new SimpleDateFormat("HH:mm:ss.SSS");
		dFormat1.setTimeZone(TimeZone.getTimeZone("GMT") );
    		return dFormat.format(dtObj)+"T"+dFormat1.format(dtObj)+"Z";
	}
}
