/*
  Copyright (c) 2007 Kathryn Huxtable

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.

  $Id: RSASignatureTest.java 495 2007-03-31 14:55:20Z huxtable $
 */
package org.kathrynhuxtable.middleware.shibshim.util;

import junit.framework.TestCase;

/**
 * Test the SampleValidator class.
 */
public class RSASignatureTest extends TestCase {
    
    private String pemCert;
    private String pemKey;

	public void setUp() {
        pemCert =
            "-----BEGIN CERTIFICATE-----\n"
            + "MIIEVDCCAzygAwIBAgIJAP24RcTW1aetMA0GCSqGSIb3DQEBBAUAMHkxCzAJBgNV\n"
            + "BAYTAlVTMRAwDgYDVQQIEwdFeGFtcGxlMRMwEQYDVQQHEwpFeGFtcGxldG9uMRsw\n"
            + "GQYDVQQKExJFeGFtcGxlIFVuaXZlcnNpdHkxCzAJBgNVBAsTAklUMRkwFwYDVQQD\n"
            + "ExBUZXN0IENlcnRpZmljYXRlMB4XDTA3MDMyOTE2NTMyNFoXDTE3MDMyNjE2NTMy\n"
            + "NFoweTELMAkGA1UEBhMCVVMxEDAOBgNVBAgTB0V4YW1wbGUxEzARBgNVBAcTCkV4\n"
            + "YW1wbGV0b24xGzAZBgNVBAoTEkV4YW1wbGUgVW5pdmVyc2l0eTELMAkGA1UECxMC\n"
            + "SVQxGTAXBgNVBAMTEFRlc3QgQ2VydGlmaWNhdGUwggEiMA0GCSqGSIb3DQEBAQUA\n"
            + "A4IBDwAwggEKAoIBAQDu4RMs8dbl7UDhbk9OclUpTz2ygT06A05w81Iv7lWRFSQS\n"
            + "g+PBRZPdOFNu8kJfP5rveibfdvQZMxysTzESno3y2yrRGDCm9aQiunx/tvDJvXrA\n"
            + "dxaJ2pUKZXAklh3KVY5fXAJgTFKzODmKtk5x7L4d4UB0gV+/d5fVLz21JVWHaN9Q\n"
            + "05ngdORgjVZYd3vw7p8ZT4IJc91niZMXRy2w4KnLSNP/qa3bVr8QAGRQTRsN0j0m\n"
            + "FnqKFMbLgL2asbOeH6AyF8FhvDIPOVW1LzkZQy9Gf2b1NlcymGMV9twjOMH+07tA\n"
            + "m7DMiGTon5AJIzVY/CEvlah8qYi602Q8irw5hMl/AgMBAAGjgd4wgdswHQYDVR0O\n"
            + "BBYEFHvsCpxRonD+WKqVTEg2+2Oy4dKGMIGrBgNVHSMEgaMwgaCAFHvsCpxRonD+\n"
            + "WKqVTEg2+2Oy4dKGoX2kezB5MQswCQYDVQQGEwJVUzEQMA4GA1UECBMHRXhhbXBs\n"
            + "ZTETMBEGA1UEBxMKRXhhbXBsZXRvbjEbMBkGA1UEChMSRXhhbXBsZSBVbml2ZXJz\n"
            + "aXR5MQswCQYDVQQLEwJJVDEZMBcGA1UEAxMQVGVzdCBDZXJ0aWZpY2F0ZYIJAP24\n"
            + "RcTW1aetMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEEBQADggEBAJ65MBZvvMjx\n"
            + "RUDS4a4EgcTbAxCd8Q4giAmKAGUMo9C3cGe+cjisiLInXp8wR1FEj44rjKLvKlKD\n"
            + "q5BgNUSMtqxj65zLOrVD9OjVa8qbbmp8cNQxSYROw2wtvgJRbBlZ85MDcczFYe4N\n"
            + "Nrst578Q77RCZCk+enEpniLi3kc0ZMMDhqLDGBUXwCswu7kWaiv+L6oqk4PWWNbh\n"
            + "Jqf9Ckf4MSzhcFILRkAxDJszvLUmQ/JWvNFfUCmCPl8dM+lT8g9h86ykqf9fVyES\n"
            + "loIIxg13uLOevDG33SCUsIUebmVSAUQKnw3xchNgtrSm0CN6P3/pzIoYdwZYN9XH\n"
            + "BV7se9Ch35I=\n"
            + "-----END CERTIFICATE-----\n";
        pemKey =
            "-----BEGIN PRIVATE KEY-----\n"
            + "MIIEvwIBADANBgkqhkiG9w0BAQEFAASCBKkwggSlAgEAAoIBAQDu4RMs8dbl7UDh\n"
            + "bk9OclUpTz2ygT06A05w81Iv7lWRFSQSg+PBRZPdOFNu8kJfP5rveibfdvQZMxys\n"
            + "TzESno3y2yrRGDCm9aQiunx/tvDJvXrAdxaJ2pUKZXAklh3KVY5fXAJgTFKzODmK\n"
            + "tk5x7L4d4UB0gV+/d5fVLz21JVWHaN9Q05ngdORgjVZYd3vw7p8ZT4IJc91niZMX\n"
            + "Ry2w4KnLSNP/qa3bVr8QAGRQTRsN0j0mFnqKFMbLgL2asbOeH6AyF8FhvDIPOVW1\n"
            + "LzkZQy9Gf2b1NlcymGMV9twjOMH+07tAm7DMiGTon5AJIzVY/CEvlah8qYi602Q8\n"
            + "irw5hMl/AgMBAAECggEBAMkknJDr0pgo/sjTqdPUUgFGyBzW1kdTIWnaeQoDFenk\n"
            + "c0tj4xOLEsbj9t0lAN5TIJMluDXSZBgUAcDVreyPtdcY1STbyZvMmzji7pJb6MT2\n"
            + "17XYkRHjDDyEzbkA7nTBNfD1+Mo9eiWO4mT6vXMQdcWTNkLj7Uu72A2aictOdIZf\n"
            + "F5uOA5PDih9SVu5of6xbXLtf+GfH4Vr9jKzMa9A31JZMyUCvFPo+0DNC33HFfOip\n"
            + "zB0mYyYPAB7B+YkzvvVunEzx5WXBS0z/oMkEbHfTLusKcfWLre1ourtmDqynsWvN\n"
            + "tRL5LyeDBMlr9Lx2ww0ZtzNDBo6SvLMlSe9fnR5DOYECgYEA/NjM7gV4VrqQvDaf\n"
            + "ZzmKHmyUpztbwn3Lyt3YbtpTf5cHCsMgcPPw+L2hhqYCheirY8ZrBmzhMaRanH7K\n"
            + "pt1f2WJ66dPyREb5jRhtLilwEry23xpGfvGDd95p6hTU50sn8bFFGjL1lQ9NtVt8\n"
            + "Gbj/tKXbHWZd7kfDAnmPp78a0qsCgYEA8duu8Sw6sF9EbBwOpQ9yHiXOIrFLNA/S\n"
            + "04hdfEY+BPO/5TsWT++xb2U1laVeoRqUrdiR2EJgwbKuXevRVqNLFnlyTPD+65A7\n"
            + "tiohnkooSjHIsWvCej5z9mfd860zZQo4g0QoMCq/ERvSRV+87qCFRhqROp7TO7Y6\n"
            + "VQwyK7hjxH0CgYAEc8TYBBykWlCmH8gaxzaZZowPjcoF2LU380QWX53Mx1oGZH0z\n"
            + "v/fkSWKIvm+Y8Ankjd/gkxY8C4rU6p6i5Y8EgulrKKJBdYZ7Z4y0nWIt0kjeENZg\n"
            + "8dvAxpfS2V8OW5JufRKcbX1JjKVvpha/VTSbd7guAllxEq5qYr2W1JSiVQKBgQDU\n"
            + "wmCfID1wsh3KzNPFOFU3WCKCOlzhq5nXI/q5PEGKsbJ5wQTbxQvd5rbAsf0Q1AU+\n"
            + "+WkzSRE81Ca30J8TDAsd9jAqp0ZZi0Q798wjJzFSM4FNMnKefxocBTsnBZJUrC0S\n"
            + "rH5+ANyb/FF5XcMiWGtlRDHF07oWqTOfZV8tPsPlMQKBgQDb1Z/SRwY2vwpixZeh\n"
            + "14p61vCys7s9IAwbd3LFb+Kdh1p+zNmUnBTktCSvqSNe17/VImYz0Qw1uh9xzrpn\n"
            + "Ch0T78IGDLRBRakkuLbmckMLKozLnsbKuNzuHuKWHsyATfeCxJ9/wVvEXmVwUa7i\n"
            + "kE3mAc5mg39t9qQXdeIsWlSVYQ==\n"
            + "-----END PRIVATE KEY-----\n";
	}

    public void testSuccess() {
        String text = "This is the forest primeval, the murmuring pines and the hemlocks";

        byte[] sigBlock = null;
        try {
            sigBlock = RSASignature.sign(text.getBytes(), pemKey);
        } catch (RSASignatureException e) {
            fail("Got exception signing text with key: " + e);
            return;
        }

        boolean status = false;
        try {
            status = RSASignature.verify(text.getBytes(), sigBlock, pemCert);
        } catch (RSASignatureException e) {
            fail("Got exception verifying signature: " + e);
            return;
        }
        assertTrue("Verification of signature failed", status);
    }
}
